@@ -232,7 +232,7 @@ public:
         use wxBaseArray anyhow it shouldn't be a problem) and that you should
         not derive your own classes from the array classes.
     */
-    //@{
+    ///@{
 
     /**
         Default constructor.
@@ -271,6 +271,14 @@ public:
     */
     wxObjArray(const wxObjArray& array);
 
+    /**
+        Constructs the container with the contents of the initializer_list @a list.
+
+        @since 3.2.4
+    */
+    template<typename T>
+    wxArray(std::initializer_list<T> list);
+
     /**
         Performs a shallow array copy (i.e.\ doesn't copy the objects pointed to
         even if the source array contains the items of pointer type).
@@ -305,7 +313,7 @@ public:
     */
     ~wxObjArray();
 
-    //@}
+    ///@}
 
 
     /**
@@ -324,7 +332,7 @@ public:
         put in the array and will prevent the array code from reallocating the
         memory more times than needed.
     */
-    //@{
+    ///@{
 
     /**
         Preallocates memory for a given number of array elements. It is worth
@@ -344,7 +352,7 @@ public:
     */
     void Shrink();
 
-    //@}
+    ///@}
 
 
     /**
@@ -354,7 +362,7 @@ public:
         allow to retrieve them - possibly using just the C array indexing []
         operator which does exactly the same as the Item() method.
     */
-    //@{
+    ///@{
 
     /**
         Return the number of items in the array.
@@ -386,13 +394,13 @@ public:
     */
     T& Last() const;
 
-    //@}
+    ///@}
 
 
     /**
         @name Adding Items
     */
-    //@{
+    ///@{
 
     /**
         Appends the given number of @a copies of the @a item to the array
@@ -507,13 +515,13 @@ public:
     */
     void SetCount(size_t count, T defval = T(0));
 
-    //@}
+    ///@}
 
 
     /**
         @name Removing Items
     */
-    //@{
+    ///@{
 
     /**
         This function does the same as Empty() and additionally frees the
@@ -580,13 +588,13 @@ public:
     */
     void RemoveAt(size_t index, size_t count = 1);
 
-    //@}
+    ///@}
 
 
     /**
         @name Searching and Sorting
     */
-    //@{
+    ///@{
 
     /**
         This version of Index() is for wxArray and wxObjArray only.
@@ -648,7 +656,7 @@ public:
     */
     void Sort(CMPFUNC<T> compareFunction);
 
-    //@}
+    ///@}
 };
 
 
@@ -665,7 +673,7 @@ public:
 */
 #define WX_CLEAR_ARRAY(wxArray_arrayToBeCleared)
 
-//@{
+///@{
 /**
     This macro declares a new object array class named @a name and containing
     the elements of type @e T.
@@ -687,9 +695,9 @@ public:
 #define WX_DECLARE_OBJARRAY(T, name)
 #define WX_DECLARE_EXPORTED_OBJARRAY(T, name)
 #define WX_DECLARE_USER_EXPORTED_OBJARRAY(T, name, expmode)
-//@}
+///@}
 
-//@{
+///@{
 /**
     This macro defines a new array class named @a name and containing the
     elements of type @a T.
@@ -714,9 +722,9 @@ public:
 #define WX_DEFINE_ARRAY(T, name)
 #define WX_DEFINE_EXPORTED_ARRAY(T, name)
 #define WX_DEFINE_USER_EXPORTED_ARRAY(T, name, exportspec)
-//@}
+///@}
 
-//@{
+///@{
 /**
     This macro defines the methods of the array class @a name not defined by
     the WX_DECLARE_OBJARRAY() macro. You must include the file
@@ -752,9 +760,9 @@ public:
 #define WX_DEFINE_OBJARRAY(name)
 #define WX_DEFINE_EXPORTED_OBJARRAY(name)
 #define WX_DEFINE_USER_EXPORTED_OBJARRAY(name)
-//@}
+///@}
 
-//@{
+///@{
 /**
     This macro defines a new sorted array class named @a name and containing
     the elements of type @e T.
@@ -795,7 +803,7 @@ public:
 #define WX_DEFINE_SORTED_ARRAY(T, name)
 #define WX_DEFINE_SORTED_EXPORTED_ARRAY(T, name)
 #define WX_DEFINE_SORTED_USER_EXPORTED_ARRAY(T, name, expmode)
-//@}
+///@}
 
 /**
     This macro may be used to prepend all elements of the @a wxArray_arrayToBePrepended
@@ -803,7 +811,7 @@ public:
 */
 #define WX_PREPEND_ARRAY(wxArray_arrayToModify, wxArray_arrayToBePrepended)
 
-//@{
+///@{
 /**
     Predefined specialization of wxArray<T> for standard types.
 */
@@ -812,4 +820,4 @@ typedef wxArray<long> wxArrayLong;
 typedef wxArray<short> wxArrayShort;
 typedef wxArray<double> wxArrayDouble;
 typedef wxArray<void*> wxArrayPtrVoid;
-//@}
+///@}
